@@ -26,4 +26,6 @@ along with Foobar.  If not, see <https://www.gnu.org/licenses/>.
 """
 
 from .main import Stack
-from .stacktools import *
\ No newline at end of file
+from .stacktools import *
+from .plot import *
+from .io import *
